[LON-CAPA-cvs] cvs: loncom / lonc lond lonsql /configuration Configuration.pm /lonnet/perl lonnet.pm /metadata_database searchcat.pl

matthew lon-capa-cvs@mail.lon-capa.org
Fri, 17 May 2002 14:03:04 -0000


matthew		Fri May 17 10:03:04 2002 EDT

  Modified files:              
    /loncom	lonc lond lonsql 
    /loncom/configuration	Configuration.pm 
    /loncom/lonnet/perl	lonnet.pm 
    /loncom/metadata_database	searchcat.pl 
  Log:
  Replaced access.conf with loncapa_apache.conf.
  
  
Index: loncom/lonc
diff -u loncom/lonc:1.40 loncom/lonc:1.41
--- loncom/lonc:1.40	Sat May 11 17:17:39 2002
+++ loncom/lonc	Fri May 17 10:03:04 2002
@@ -5,7 +5,7 @@
 # provides persistent TCP connections to the other servers in the network
 # through multiplexed domain sockets
 #
-# $Id: lonc,v 1.40 2002/05/11 21:17:39 harris41 Exp $
+# $Id: lonc,v 1.41 2002/05/17 14:03:04 matthew Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -75,9 +75,10 @@
 $SIG{QUIT}=\&catchexception;
 $SIG{__DIE__}=\&catchexception;
 
-# ------------------------------------------- Read access.conf and loncapa.conf
-&status("Read access.conf and loncapa.conf");
-my $perlvarref=LONCAPA::Configuration::read_conf('access.conf','loncapa.conf');
+# ---------------------------------- Read loncapa_apache.conf and loncapa.conf
+&status("Read loncapa_apache.conf and loncapa.conf");
+my $perlvarref=LONCAPA::Configuration::read_conf('loncapa_apache.conf',
+                                                 'loncapa.conf');
 my %perlvar=%{$perlvarref};
 undef $perlvarref;
 
Index: loncom/lond
diff -u loncom/lond:1.80 loncom/lond:1.81
--- loncom/lond:1.80	Sat May 11 17:24:56 2002
+++ loncom/lond	Fri May 17 10:03:04 2002
@@ -2,7 +2,7 @@
 # The LearningOnline Network
 # lond "LON Daemon" Server (port "LOND" 5663)
 #
-# $Id: lond,v 1.80 2002/05/11 21:24:56 harris41 Exp $
+# $Id: lond,v 1.81 2002/05/17 14:03:04 matthew Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -105,9 +105,10 @@
 $SIG{'QUIT'}=\&catchexception;
 $SIG{__DIE__}=\&catchexception;
 
-# ------------------------------------------- Read access.conf and loncapa.conf
-&status("Read access.conf and loncapa.conf");
-my $perlvarref=LONCAPA::Configuration::read_conf('access.conf','loncapa.conf');
+# ---------------------------------- Read loncapa_apache.conf and loncapa.conf
+&status("Read loncapa_apache.conf and loncapa.conf");
+my $perlvarref=LONCAPA::Configuration::read_conf('loncapa_apache.conf',
+                                                 'loncapa.conf');
 my %perlvar=%{$perlvarref};
 undef $perlvarref;
 
Index: loncom/lonsql
diff -u loncom/lonsql:1.42 loncom/lonsql:1.43
--- loncom/lonsql:1.42	Sat May 11 17:26:53 2002
+++ loncom/lonsql	Fri May 17 10:03:04 2002
@@ -3,7 +3,7 @@
 # The LearningOnline Network
 # lonsql - LON TCP-MySQL-Server Daemon for handling database requests.
 #
-# $Id: lonsql,v 1.42 2002/05/11 21:26:53 harris41 Exp $
+# $Id: lonsql,v 1.43 2002/05/17 14:03:04 matthew Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -46,7 +46,7 @@
 ## ORGANIZATION OF THIS PERL SCRIPT                                          ##
 ## 1. Modules used                                                           ##
 ## 2. Enable find subroutine                                                 ##
-## 3. Read httpd access.conf and get variables                               ##
+## 3. Read httpd config files and get variables                              ##
 ## 4. Make sure that database can be accessed                                ##
 ## 5. Make sure this process is running from user=www                        ##
 ## 6. Check if other instance is running                                     ##
@@ -80,8 +80,9 @@
 $childmaxattempts=10;
 $run =0;#running counter to generate the query-id
 
-# ------------------------------------------- Read access.conf and loncapa.conf
-my $perlvarref=LONCAPA::Configuration::read_conf('access.conf','loncapa.conf');
+# -------------------------------- Read loncapa_apache.conf and loncapa.conf
+my $perlvarref=LONCAPA::Configuration::read_conf('loncapa_apache.conf',
+                                                 'loncapa.conf');
 my %perlvar=%{$perlvarref};
 
 # ------------------------------------- Make sure that database can be accessed
Index: loncom/configuration/Configuration.pm
diff -u loncom/configuration/Configuration.pm:1.5 loncom/configuration/Configuration.pm:1.6
--- loncom/configuration/Configuration.pm:1.5	Thu May 16 13:24:06 2002
+++ loncom/configuration/Configuration.pm	Fri May 17 10:03:04 2002
@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Configuration file reader
 #
-# $Id: Configuration.pm,v 1.5 2002/05/16 17:24:06 harris41 Exp $
+# $Id: Configuration.pm,v 1.6 2002/05/17 14:03:04 matthew Exp $
 #
 #
 # Copyright Michigan State University Board of Trustees
@@ -33,7 +33,7 @@
 
 package LONCAPA::Configuration;
 
-$VERSION = sprintf("%d.%02d", q$Revision: 1.5 $ =~ /(\d+)\.(\d+)/);
+$VERSION = sprintf("%d.%02d", q$Revision: 1.6 $ =~ /(\d+)\.(\d+)/);
 
 use strict;
 
@@ -71,14 +71,7 @@
  use lib '/home/httpd/lib/perl/';
  use LONCAPA::Configuration;
 
- LONCAPA::Configuration::read_conf('access.conf','loncapa.conf');
-
-In the future, standard invocation of the command will be:
-
- LONCAPA::Configuration::read_conf('loncapa.conf');
-
-F<access.conf> is slowly becoming deprecated.  (We are currently
-trying to support backwards compatibility.)
+ LONCAPA::Configuration::read_conf('loncapa_apache.conf','loncapa.conf');
 
 =head1 DESCRIPTION
 
Index: loncom/lonnet/perl/lonnet.pm
diff -u loncom/lonnet/perl/lonnet.pm:1.222 loncom/lonnet/perl/lonnet.pm:1.223
--- loncom/lonnet/perl/lonnet.pm:1.222	Fri May 17 07:39:48 2002
+++ loncom/lonnet/perl/lonnet.pm	Fri May 17 10:03:04 2002
@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # TCP networking package
 #
-# $Id: lonnet.pm,v 1.222 2002/05/17 11:39:48 matthew Exp $
+# $Id: lonnet.pm,v 1.223 2002/05/17 14:03:04 matthew Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -2804,12 +2804,12 @@
 }
 
 BEGIN {
 # ------------------------------------------- Read access.conf and loncapa.conf
 # (eventually access.conf will become deprecated)
     unless ($readit) {
 
 {
-    my $config=Apache::File->new("/etc/httpd/conf/access.conf");
+    my $config=Apache::File->new("/etc/httpd/conf/loncapa_apache.conf");
 
     while (my $configline=<$config>) {
         if ($configline =~ /^[^\#]*PerlSetVar/) {
@@ -2804,12 +2804,12 @@
 
 BEGIN {
-# ------------------------------------------- Read access.conf and loncapa.conf
+# ---------------------------------- Read loncapa_apache.conf and loncapa.conf
 # (eventually access.conf will become deprecated)
     unless ($readit) {
Index: loncom/metadata_database/searchcat.pl
diff -u loncom/metadata_database/searchcat.pl:1.17 loncom/metadata_database/searchcat.pl:1.18
--- loncom/metadata_database/searchcat.pl:1.17	Sat May 11 17:28:20 2002
+++ loncom/metadata_database/searchcat.pl	Fri May 17 10:03:04 2002
@@ -2,7 +2,7 @@
 # The LearningOnline Network
 # searchcat.pl "Search Catalog" batch script
 #
-# $Id: searchcat.pl,v 1.17 2002/05/11 21:28:20 harris41 Exp $
+# $Id: searchcat.pl,v 1.18 2002/05/17 14:03:04 matthew Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -55,8 +55,9 @@
     push(@metalist,"$dir/$_");
 }
 
-# ------------------------- Read access.conf and loncapa.conf and get variables
-my $perlvarref=LONCAPA::Configuration::read_conf('access.conf','loncapa.conf');
+# ---------------  Read loncapa_apache.conf and loncapa.conf and get variables
+my $perlvarref=LONCAPA::Configuration::read_conf('loncapa_apache.conf',
+                                                 'loncapa.conf');
 my %perlvar=%{$perlvarref};
 undef $perlvarref; # remove since sensitive and not needed
 delete $perlvar{'lonReceipt'}; # remove since sensitive and not needed